'use strict';
/** @jsx createElement */
import { PropTypes,Component,createElement } from 'weex-rx';
import pickerStyles from './style.rxscss';

import {TouchableHighlight, Text,View} from 'nuke-components';
const noop = () => {};

class Picker extends Component {

    static propTypes = {
        title: PropTypes.node,
        footer: PropTypes.node,
        visible: PropTypes.bool,
        hasMask: PropTypes.bool,
        closable: PropTypes.bool,
        maskClosable: PropTypes.bool,
        onSelect: PropTypes.func,
        onCancel: PropTypes.func,
        onClose: PropTypes.func,
        defaultVisible: PropTypes.bool,
        locale: PropTypes.shape({
            ok: PropTypes.string,
            cancel: PropTypes.string
        }),
        animation: PropTypes.oneOfType([PropTypes.bool, PropTypes.shape({
            'in': PropTypes.string,
            'out': PropTypes.string
        })])
    }

    static defaultProps = {
        title: 'Title',
        hasMask: true,
        closable: false,
        maskClosable: false,
        defaultVisible: false,
        locale: {
            ok: 'Ok',
            cancel: 'Cancel'
        },
        animation: {
            'in': 'zoomIn',
            'out': 'zoomOut'
        },
        onSelect: noop,
        onCancel: noop,
        onClose: noop
    }

    constructor(props) {
        super(props);

        let visible;

        if ('visible' in props) {
            visible = props.visible;
        } else {
            visible = props.defaultVisible;
        }

        this.state = { visible };

        ['onSelect', 'onCancel', 'onClose', 'onMaskClose'].forEach((m) => {
            this[m] = this[m].bind(this);
        });
    }

    componentWillReceiveProps(nextProps) {
        if ('visible' in nextProps) {
            this.setState({
                visible: nextProps.visible
            })
        }
    }

    shouldComponentUpdate(nextProps, nextState) {
        return !!(this.state.visible || nextState.visible);
    }

    componentDidMount() {

        // todo: resize -> position
        this.componentDidUpdate()
    }

    componentDidUpdate() {
        if (this.state.visible) {
            this.position();
        }
    }

    position() {
        const dialog = this.refs.dialog;

       
    }

    show() {
        this.setState({
            visible: true
        });
    }

    hide() {
        this.setState({
            visible: false
        });
    }

    onSelect(info,e) {

        if (!('visible' in this.props)) {
            this.hide();
        }

        this.props.onSelect(info);
    }

    onCancel(e) {

        if (!('visible' in this.props)) {
            this.hide();
        }

        this.props.onCancel({type:'cancel'});
    }

    onClose(e) {

        if (!('visible' in this.props)) {
            this.hide();
        }
    }

    onMaskClose(e) {

        if (!this.props.maskClosable) {
            return;
        }

        this.onClose(e);
    }

    // afterOpen() {
    //     this.props.afterOpen(this);
    // }

    // afterClose() {
    //     this.props.afterClose();
    // }
    getContent(){
        let dom=[];
        const { title , options, cancelButtonIndex , destructiveButtonIndex } = this.props;
        options.forEach((item,index)=>{
            if(index !== destructiveButtonIndex && index !== cancelButtonIndex ){
            
                dom.push(<TouchableHighlight onPress={this.onSelect.bind(this,{buttonIndex:index,type:'button'})} style={pickerStyles['nukeASItem']}><Text style={pickerStyles['nukeASItemText']}>{item}</Text></TouchableHighlight>)
            }
            
        });
        if(destructiveButtonIndex){
            dom.push(<TouchableHighlight onPress={this.onSelect.bind(this,{buttonIndex:destructiveButtonIndex,type:'destructive'})} style={pickerStyles['nukeASItem']}><Text style={[pickerStyles['nukeASItemText'],pickerStyles['nukeASItemDestructiveText']]}>{options[destructiveButtonIndex]}</Text></TouchableHighlight>)
        }   
        if(cancelButtonIndex){
            dom.push(<View style={pickerStyles['nukeASItemSeparator']}></View>)
            dom.push(<TouchableHighlight onPress={this.onCancel.bind(this,{type:'cancel'})} style={pickerStyles['nukeASItem']}><Text style={pickerStyles['nukeASItemText']}>{options[cancelButtonIndex]}</Text></TouchableHighlight>)

        }
        return dom;
    }
    render() {

        const { visible } = this.state;
        const { title, animation, options, cancelButtonIndex , destructiveButtonIndex ,
            hasMask, locale = {}, style = {}, prefix = this.defaultPrefix } = this.props;

        

        let styleSet = {...style},
            zIndex = styleSet.zIndex,
            { header } = this.props;

        if ( header === undefined ) {
            header = (
                <View style={pickerStyles['nukeASHeader']}>
                    
                    <Text style={pickerStyles['nukeASTitle']}>{title}</Text>
                </View>
            );
        }

        if (zIndex === undefined) {
            zIndex = 499;
            styleSet['zIndex'] = zIndex;
        }
        const visibility={visibility:visible?'visible':'hidden'};
        return (
            <TouchableHighlight style={[pickerStyles['nukeASMask'],visibility]} onPress={this.onMaskClose}>
                <View style={pickerStyles['nukeAS']}  animation={animation}>
                    { header ? header : null }

                    <View style={pickerStyles['nukeASContent']}>
                        { this.getContent(options) }
                    </View>
                        
                </View>
            </TouchableHighlight>
        );
    }
}

export default Picker;
