'use strict';
/** @jsx createElement */
import {unmountComponentAtNode,findDOMNode,createElement} from 'weex-rx';
import {mount} from 'nuke-mounter';
import ActionSheet from './actionsheet';
import {env} from 'nuke-core';
const isWeex = env.isWeex;
const noop = () => {};

const defaultOptions = {
    title: '',
    onCancel: noop,
    onSelect: noop
};

const dialogInstances = [];

export function show (paramOptions={},onSelect,onCancel) {

    paramOptions = {...defaultOptions, ...paramOptions};
    // ignore `visible` attribute for uncontrolled dialog
    const { title, options,cancelButtonIndex, destructiveButtonIndex, ...others } = paramOptions;

    if(isWeex){
        let AS = require('@weex-module/qapactionsheet');

        AS.show({
            options: options,
            cancelButtonIndex: cancelButtonIndex,
            destructiveButtonIndex: destructiveButtonIndex,
            title:title
        }, (ret) => {
             onSelect && onSelect(ret)
        }, (err) => {
            onCancel && onCancel(err)
        }, (info) => {

            onSelect && onSelect(info)
        });

    }else{

        let dialog;
        let container  = document.createElement('div');

        dialog = (
            <ActionSheet {...others} defaultVisible={true} title={title}
                onSelect={onSelectCallback} onCancel={onCancelCallback} options={options} cancelButtonIndex={cancelButtonIndex} destructiveButtonIndex={destructiveButtonIndex}>
            </ActionSheet>
        );

        function onCancelCallback(e) {
            unmountComponentAtNode(container);
            document.body.removeChild(container);

            onCancel(e);
            container = dialog = null;
        }

        function onSelectCallback(d) {
            onSelect(d);
        }

        document.body.appendChild(container);
        mount(dialog, container, function () {
            dialogInstances.push(this);
        });
    }
};

export function hide (instance) {

    let index;

    if (instance && (index = dialogInstances.indexOf(instance)) > -1) {
        dialogInstances.splice(index, 1);
    } else {
        instance = dialogInstances.pop();
    }

    if (instance) {
        instance.hide();
    }
}
